// This file is auto-generated by @hey-api/openapi-ts

export type AnonymizedWorkflowExecution = {
  /**
   * ID of the workflow execution
   */
  workflow_execution_id: string;
  /**
   * Anonymized user ID of the user who ran the workflow execution
   */
  pseudo_uid: string;
  /**
   * ID of the workflow mode this workflow execution ran in
   */
  workflow_mode_id?: string | null;
  /**
   * Hash of the git commit
   */
  workflow_version_id: string;
  /**
   * Day of the workflow execution
   */
  started_at: string;
  /**
   * ID of the workflow
   */
  workflow_id: string;
  /**
   * ID of developer of the workflow
   */
  developer_id: string;
  /**
   * End status of the workflow execution
   */
  status: WorkflowExecutionStatus;
};

export type ApiTokenIn = {
  /**
   * Short name for the API token
   */
  name: string;
  /**
   * Unix timestamp when the token should expire
   */
  expires_at?: number | null;
  /**
   * List of scopes this Api token has
   */
  scopes: Array<"read" | "write">;
};

export type ApiTokenOut = {
  /**
   * Short name for the API token
   */
  name: string;
  /**
   * Unix timestamp when the token should expire
   */
  expires_at?: number | null;
  /**
   * List of scopes this Api token has
   */
  scopes: Array<"read" | "write">;
  /**
   * The ID of the token
   */
  token_id: string;
  /**
   * The ID of the owner
   */
  uid: string;
  /**
   * The UNIX timestamp when this token was created
   */
  created_at: number;
  /**
   * The UNIX timestamp when this token was used the last time
   */
  last_used?: number | null;
};

export type ApiTokenPrivateOut = {
  /**
   * Short name for the API token
   */
  name: string;
  /**
   * Unix timestamp when the token should expire
   */
  expires_at?: number | null;
  /**
   * List of scopes this Api token has
   */
  scopes: Array<"read" | "write">;
  /**
   * The ID of the token
   */
  token_id: string;
  /**
   * The ID of the owner
   */
  uid: string;
  /**
   * The UNIX timestamp when this token was created
   */
  created_at: number;
  /**
   * The UNIX timestamp when this token was used the last time
   */
  last_used?: number | null;
  /**
   * The actual token used for authentication
   */
  token: string;
};

export type Body_Bucket_update_bucket_public_state = {
  /**
   * New public state
   */
  public: boolean;
};

export type Body_Workflow_Version_upload_workflow_version_icon = {
  /**
   * Icon for the Workflow.
   */
  icon: Blob | File;
};

/**
 * Schema for creating a new bucket.
 */
export type BucketIn = {
  /**
   * Name of the bucket
   */
  name: string;
  /**
   * Description of the bucket
   */
  description: string;
};

/**
 * Schema for answering a request with a bucket.
 */
export type BucketOut = {
  /**
   * Size limit of the bucket in KiB
   */
  size_limit?: number | null;
  /**
   * Number of objects limit of the bucket
   */
  object_limit?: number | null;
  /**
   * Name of the bucket
   */
  name: string;
  /**
   * Description of the bucket
   */
  description: string;
  /**
   * UNIX timestamp when the bucket was created
   */
  created_at: number;
  /**
   * UID of the owner
   */
  owner_id: string;
  /**
   * Flag if the bucket is anonymously readable
   */
  public: boolean;
};

export type BucketPermissionIn = {
  /**
   * Start date of permission as UNIX timestamp
   */
  from_timestamp?: number | null;
  /**
   * End date of permission as UNIX timestamp
   */
  to_timestamp?: number | null;
  /**
   * Prefix of subfolder
   */
  file_prefix?: string | null;
  /**
   * Scopes of the bucket permission
   */
  scopes: Array<"read" | "write">;
  /**
   * UID of the grantee
   */
  uid: string;
  /**
   * Name of Bucket
   */
  bucket_name: string;
};

/**
 * Schema for the bucket permissions.
 */
export type BucketPermissionOut = {
  /**
   * Start date of permission as UNIX timestamp
   */
  from_timestamp?: number | null;
  /**
   * End date of permission as UNIX timestamp
   */
  to_timestamp?: number | null;
  /**
   * Prefix of subfolder
   */
  file_prefix?: string | null;
  /**
   * Scopes of the bucket permission
   */
  scopes: Array<"read" | "write">;
  /**
   * UID of the grantee
   */
  uid: string;
  /**
   * Name of Bucket
   */
  bucket_name: string;
};

/**
 * Schema for the parameters of a bucket permission.
 */
export type BucketPermissionParameters = {
  /**
   * Start date of permission as UNIX timestamp
   */
  from_timestamp?: number | null;
  /**
   * End date of permission as UNIX timestamp
   */
  to_timestamp?: number | null;
  /**
   * Prefix of subfolder
   */
  file_prefix?: string | null;
  /**
   * Scopes of the bucket permission
   */
  scopes: Array<"read" | "write">;
};

/**
 * Schema to represent bucket limits.
 */
export type BucketSizeLimits = {
  /**
   * Size limit of the bucket in KiB
   */
  size_limit?: number | null;
  /**
   * Number of objects limit of the bucket
   */
  object_limit?: number | null;
};

/**
 * Enumeration for the type of buckets to fetch from the DB
 *
 * OWN: Only fetch buckets that the user owns
 * PERMISSION: Only fetch foreign buckets that the user has access to
 * ALL: Fetch all buckets that the user has access to
 */
export enum BucketType {
  OWN = "OWN",
  ALL = "ALL",
  PERMISSION = "PERMISSION",
}

export type DevWorkflowExecutionIn = {
  /**
   * Parameters for this workflow
   */
  parameters: {
    [key: string]: unknown;
  };
  /**
   * S3 Path where to save logs and reports. If None, nothing will be uploaded.
   */
  logs_s3_path?: string | null;
  /**
   * S3 Path where to save provenance information. If None, nothing will be uploaded.
   */
  provenance_s3_path?: string | null;
  /**
   * S3 Path where to save debug information from Nextflow. If None, nothing will be uploaded.
   */
  debug_s3_path?: string | null;
  /**
   * Hash of the git commit
   */
  git_commit_hash: string;
  /**
   * URL to the Git repository belonging to this workflow
   */
  repository_url: string;
  /**
   * Token to access the content git repository
   */
  token?: string | null;
  /**
   * Mode of the workflow with an alternative entrypoint
   */
  mode?: WorkflowModeIn | null;
  /**
   * The version of Nextflow this workflow execution requires
   */
  nextflow_version: NextflowVersion;
};

export enum DocumentationEnum {
  USAGE_MD = "usage.md",
  INPUT_MD = "input.md",
  OUTPUT_MD = "output.md",
  CHANGELOG_MD = "changelog.md",
  PARAMETER_SCHEMA_JSON = "parameter_schema.json",
  CLOWM_INFO_JSON = "clowm_info.json",
  CITATIONS_MD = "CITATIONS.md",
}

/**
 * Schema for a error due to a rejected request.
 */
export type ErrorDetail = {
  /**
   * Detail about the occurred error
   */
  detail: string;
};

export type FileTree = {
  type: "file" | "directory" | "link";
  name: string;
  target?: string | null;
  contents?: Array<FileTree> | null;
  size: number;
};

export enum type {
  FILE = "file",
  DIRECTORY = "directory",
  LINK = "link",
}

export type HTTPValidationError = {
  detail?: Array<ValidationError>;
};

export type IconUpdateOut = {
  /**
   * URL to the uploaded icon
   */
  icon_url: string;
};

export type InstanceSpecificDefaultParameters = {
  [key: string]: string | number | boolean;
};

export type NewsIn = {
  /**
   * Content of the news. Can contain Markdown.
   */
  content: string;
  /**
   * Title of the news
   */
  title: string;
  /**
   * UNIX timestamp till the news is important.
   */
  important_till?: number | null;
  /**
   * Category of the news event
   */
  category?: "workflow" | "resource" | "system";
};

/**
 * Category of the news event
 */
export enum category {
  WORKFLOW = "workflow",
  RESOURCE = "resource",
  SYSTEM = "system",
}

export type NewsOut = {
  /**
   * Content of the news. Can contain Markdown.
   */
  content: string;
  /**
   * Title of the news
   */
  title: string;
  /**
   * UNIX timestamp till the news is important.
   */
  important_till?: number | null;
  /**
   * Category of the news event
   */
  category: "workflow" | "resource" | "system";
  /**
   * ID of the news event
   */
  news_id: string;
  /**
   * ID of the creator
   */
  creator_id?: string | null;
  /**
   * UNIX timestamp when the bucket was created
   */
  created_at: number;
};

export enum NextflowVersion {
  _22_10_0 = "22.10.0",
  _22_10_1 = "22.10.1",
  _22_10_2 = "22.10.2",
  _22_10_3 = "22.10.3",
  _22_10_4 = "22.10.4",
  _22_10_5 = "22.10.5",
  _22_10_6 = "22.10.6",
  _22_10_7 = "22.10.7",
  _22_10_8 = "22.10.8",
  _23_04_0 = "23.04.0",
  _23_04_1 = "23.04.1",
  _23_04_2 = "23.04.2",
  _23_04_3 = "23.04.3",
  _23_04_4 = "23.04.4",
  _23_04_5 = "23.04.5",
  _23_10_0 = "23.10.0",
  _23_10_1 = "23.10.1",
  _23_10_2 = "23.10.2",
  _23_10_3 = "23.10.3",
  _23_10_4 = "23.10.4",
  _24_04_1 = "24.04.1",
  _24_04_2 = "24.04.2",
  _24_04_3 = "24.04.3",
  _24_04_4 = "24.04.4",
  _24_10_0 = "24.10.0",
}

export enum OIDCProvider {
  LIFESCIENCE = "lifescience",
}

export type OwnershipTransferRequestIn = {
  /**
   * The new owner that get the request
   */
  new_owner_uid: string;
  /**
   * An optional comment for the transfer request
   */
  comment?: string | null;
};

export type OwnershipTransferRequestOut = {
  /**
   * The new owner that get the request
   */
  new_owner_uid: string;
  /**
   * An optional comment for the transfer request
   */
  comment?: string;
  /**
   * Time when the ownership transfer was requested as UNIX timestamp
   */
  created_at: number;
  /**
   * The current uid of the current owner if he exists
   */
  current_owner_uid?: string | null;
  /**
   * Id of the target that gets its ownership transferred
   */
  target_id: string;
  /**
   * Name of the target
   */
  target_name: string;
  /**
   * Description of then target
   */
  target_description: string;
  /**
   * Target type of the ownership transfer
   */
  target_type: OwnershipTypeEnum;
};

export enum OwnershipTypeEnum {
  BUCKET = "bucket",
  WORKFLOW = "workflow",
  RESOURCE = "resource",
}

export type ParameterExtension_Input = {
  /**
   * The inner dictionary contains the display name as key and the parameter value as value. The outer dictionary has the parameter name as key.
   */
  mapping?: {
    [key: string]: {
      [key: string]: string | number;
    };
  };
  /**
   * Dictionary with parameter name as key and default value as value
   */
  defaults?: InstanceSpecificDefaultParameters;
  parameter_visibility?: ParameterVisibilityMapping;
};

export type ParameterExtension_Output = {
  /**
   * The inner dictionary contains the display name as key and the parameter value as value. The outer dictionary has the parameter name as key.
   */
  mapping?: {
    [key: string]: {
      [key: string]: string | number;
    };
  };
  /**
   * Dictionary with parameter name as key and default value as value
   */
  defaults?: InstanceSpecificDefaultParameters;
  parameter_visibility?: ParameterVisibilityMapping;
};

export enum ParameterVisibility {
  SIMPLE = 10,
  ADVANCED = 20,
  EXPERT = 30,
  INVISIBLE = 40,
}

export type ParameterVisibilityMapping = {
  [key: string]: ParameterVisibility;
};

/**
 * Status of a bucket permission. Can be either `ACTIVE` or `INACTIVE`. A permission can only get `INACTIVE` if the
 * permission itself has a time limit and the current time is not in the timespan.
 */
export enum PermissionStatus {
  ACTIVE = "ACTIVE",
  INACTIVE = "INACTIVE",
}

export type ResourceIn = {
  /**
   * Short tag describing the version of the resource
   */
  release: string;
  /**
   * Short Name for the resource
   */
  name: string;
  /**
   * Short description for this resource
   */
  description: string;
  /**
   * A link or similar where the resource originates from
   */
  source: string;
  /**
   * Flag if this resource should be default visible in the UI
   */
  private?: boolean;
};

export type ResourceOut = {
  /**
   * Short Name for the resource
   */
  name: string;
  /**
   * Short description for this resource
   */
  description: string;
  /**
   * A link or similar where the resource originates from
   */
  source: string;
  /**
   * Flag if this resource should be default visible in the UI
   */
  private?: boolean;
  /**
   * ID of the resource
   */
  resource_id: string;
  /**
   * ID of the maintainer
   */
  maintainer_id: string | null;
  /**
   * Versions of the resource
   */
  versions: Array<ResourceVersionOut>;
};

export type ResourceVersionIn = {
  /**
   * Short tag describing the version of the resource
   */
  release: string;
};

export type ResourceVersionOut = {
  /**
   * Short tag describing the version of the resource
   */
  release: string;
  /**
   * Status of the resource version
   */
  status: ResourceVersionStatus;
  /**
   * ID of the resource version
   */
  resource_version_id: string;
  /**
   * ID of the resource
   */
  resource_id: string;
  /**
   * Timestamp when the version was created as UNIX timestamp
   */
  created_at: number;
  /**
   * Size of the compressed resource in bytes
   */
  compressed_size: number;
  /**
   * Path to the resource on the cluster if the resource is synchronized
   */
  readonly cluster_path: string;
  /**
   * Path to the resource in the S3 Bucket. Not publicly available.
   */
  readonly s3_path: string;
};

/**
 * Enumeration for the possible status of a resource version.
 */
export enum ResourceVersionStatus {
  RESOURCE_REQUESTED = "RESOURCE_REQUESTED",
  WAIT_FOR_REVIEW = "WAIT_FOR_REVIEW",
  DENIED = "DENIED",
  APPROVED = "APPROVED",
  SYNC_REQUESTED = "SYNC_REQUESTED",
  SYNCHRONIZING = "SYNCHRONIZING",
  SYNC_ERROR = "SYNC_ERROR",
  SYNCHRONIZED = "SYNCHRONIZED",
  SETTING_LATEST = "SETTING_LATEST",
  LATEST = "LATEST",
  CLUSTER_DELETING = "CLUSTER_DELETING",
  CLUSTER_DELETE_ERROR = "CLUSTER_DELETE_ERROR",
  S3_DELETING = "S3_DELETING",
  S3_DELETE_ERROR = "S3_DELETE_ERROR",
  S3_DELETED = "S3_DELETED",
}

export enum RoleEnum {
  ADMINISTRATOR = "administrator",
  USER = "user",
  REVIEWER = "reviewer",
  DEVELOPER = "developer",
  DB_MAINTAINER = "db_maintainer",
}

/**
 * Schema for a S3 key associated with a user.
 */
export type S3Key = {
  /**
   * UID of the user of that access key
   */
  uid: string;
  /**
   * ID of the S3 access key
   */
  access_key: string;
  /**
   * Secret of the S3 access key
   */
  secret_key: string;
};

export type UserIn = {
  /**
   * Full Name of the user
   */
  display_name: string;
  roles?: Array<RoleEnum>;
  /**
   * Email of the user
   */
  email: string;
};

/**
 * Schema for a user.
 */
export type UserOut = {
  /**
   * Full Name of the user
   */
  display_name: string;
  /**
   * ID of the user
   */
  uid: string;
};

export type UserOutExtended = {
  /**
   * Roles of the user
   */
  roles: Array<RoleEnum>;
  /**
   * Full Name of the user
   */
  display_name: string;
  /**
   * ID of the user
   */
  uid: string;
  /**
   * Lifesicence ID of the user
   */
  lifescience_id?: string | null;
  /**
   * Timestamp when the invitation token was created as UNIX timestamp
   */
  invitation_token_created_at?: number | null;
  /**
   * URL to the gravatar avatar based on the users email
   */
  gravatar_url: string;
};

export type UserRequestAnswer = {
  /**
   * Flag to indicate if the request was denied.
   */
  deny?: boolean;
  /**
   * Reason why the request was denied or approved. Required if request is denied.
   */
  reason?: string | null;
};

export type UserRoles = {
  /**
   * Roles of the user
   */
  roles: Array<RoleEnum>;
};

export type UserSynchronizationRequestIn = {
  /**
   * Reason why the request was requested.
   */
  reason: string;
};

export type UserSynchronizationRequestOut = {
  /**
   * Reason why the request was requested.
   */
  reason: string;
  /**
   * ID of the resource version
   */
  resource_version_id: string;
  /**
   * ID of the resource
   */
  resource_id: string;
  /**
   * ID of the user that requested this resource synchronization
   */
  requester_id: string;
};

export type ValidationError = {
  loc: Array<string | number>;
  msg: string;
  type: string;
};

export type WorkflowCredentialsIn = {
  /**
   * Token to access the content git repository
   */
  token: string;
};

export type WorkflowCredentialsOut = {
  /**
   * Token to access the content git repository
   */
  token?: string | null;
};

export type WorkflowExecutionIn = {
  /**
   * Parameters for this workflow
   */
  parameters: {
    [key: string]: unknown;
  };
  /**
   * S3 Path where to save logs and reports. If None, nothing will be uploaded.
   */
  logs_s3_path?: string | null;
  /**
   * S3 Path where to save provenance information. If None, nothing will be uploaded.
   */
  provenance_s3_path?: string | null;
  /**
   * S3 Path where to save debug information from Nextflow. If None, nothing will be uploaded.
   */
  debug_s3_path?: string | null;
  /**
   * Workflow version git commit hash
   */
  workflow_version_id: string;
  /**
   * Optional notes for this workflow execution
   */
  notes?: string | null;
  /**
   * ID of the workflow mode this workflow execution runs in
   */
  mode_id?: string | null;
};

export type WorkflowExecutionOut = {
  /**
   * Workflow version git commit hash
   */
  workflow_version_id?: string | null;
  /**
   * Optional notes for this workflow execution
   */
  notes?: string | null;
  /**
   * ID of the workflow mode this workflow execution runs in
   */
  mode_id?: string | null;
  /**
   * ID of the workflow execution
   */
  execution_id: string;
  /**
   * UID of user who started the workflow
   */
  executor_id?: string | null;
  /**
   * Start time of the workflow execution as UNIX timestamp
   */
  start_time: number;
  /**
   * End time of the workflow execution as UNIX timestamp
   */
  end_time?: number | null;
  /**
   * Status of the workflow execution
   */
  status: WorkflowExecutionStatus;
  /**
   * Id of the workflow
   */
  workflow_id?: string | null;
  /**
   * S3 Path where logs and reports are saved.
   */
  logs_s3_path?: string | null;
  /**
   * S3 Path where provenance information is saved.
   */
  provenance_s3_path?: string | null;
  /**
   * S3 Path where debug information from Nextflow is saved.
   */
  debug_s3_path?: string | null;
  /**
   * The consumed cpu time in ISO 8601 format
   */
  cpu_time: string;
};

/**
 * Enumeration for the status on a workflow execution.
 */
export enum WorkflowExecutionStatus {
  PENDING = "PENDING",
  SCHEDULED = "SCHEDULED",
  RUNNING = "RUNNING",
  CANCELED = "CANCELED",
  SUCCESS = "SUCCESS",
  ERROR = "ERROR",
}

export type WorkflowIn = {
  /**
   * Short descriptive name of the workflow
   */
  name: string;
  /**
   * Short description of the workflow
   */
  short_description: string;
  /**
   * URL to the Git repository belonging to this workflow
   */
  repository_url: string;
  /**
   * Hash of the git commit
   */
  git_commit_hash: string;
  /**
   * Version of the Workflow. Should follow semantic versioning
   */
  initial_version: string;
  /**
   * Token to access the content git repository
   */
  token?: string | null;
  /**
   * List of modes with alternative entrypoint the new workflow has
   */
  modes?: Array<WorkflowModeIn>;
  /**
   * The version of Nextflow this workflow version requires.
   */
  nextflow_version: NextflowVersion;
};

export type WorkflowModeIn = {
  /**
   * Path to the alternative parameter schema
   */
  schema_path: string;
  /**
   * Name of the process the workflow should start with. Argument to the parameter '-entry'
   */
  entrypoint: string;
  /**
   * Name of the workflow mode
   */
  name: string;
};

export type WorkflowModeOut = {
  /**
   * Path to the alternative parameter schema
   */
  schema_path: string;
  /**
   * Name of the process the workflow should start with. Argument to the parameter '-entry'
   */
  entrypoint: string;
  /**
   * Name of the workflow mode
   */
  name: string;
  /**
   * ID of the workflow mode
   */
  mode_id: string;
};

export type WorkflowOut = {
  /**
   * Short descriptive name of the workflow
   */
  name: string;
  /**
   * Short description of the workflow
   */
  short_description: string;
  /**
   * URL to the Git repository belonging to this workflow
   */
  repository_url: string;
  /**
   * ID of the workflow
   */
  workflow_id: string;
  /**
   * Versions of the workflow
   */
  versions: Array<WorkflowVersion>;
  /**
   * ID of developer of the workflow
   */
  developer_id?: string | null;
  /**
   * Flag if the workflow is hosted in a private git repository
   */
  private?: boolean;
};

export type WorkflowStatistic = {
  /**
   * Day of the datapoint
   */
  day: string;
  /**
   * Number of started workflows on that day
   */
  count: number;
};

export type WorkflowUpdate = {
  /**
   * Version of the Workflow. Should follow semantic versioning
   */
  version: string;
  /**
   * Hash of the git commit
   */
  git_commit_hash: string;
  /**
   * Add modes to the new workflow version
   */
  append_modes?: Array<WorkflowModeIn>;
  /**
   * Delete modes for the new workflow version.
   */
  delete_modes?: Array<string>;
};

export type WorkflowVersion = {
  /**
   * Status of the workflow version
   */
  status: WorkflowVersionStatus;
  /**
   * ID of the corresponding workflow
   */
  workflow_id: string;
  /**
   * Version of the Workflow. Should follow semantic versioning
   */
  version: string;
  /**
   * URL to the uploaded icon
   */
  icon_url?: string | null;
  /**
   * Hash of the git commit
   */
  workflow_version_id: string;
  /**
   * Timestamp when the version was created as UNIX timestamp
   */
  created_at: number;
  /**
   * Optional modes his workflow version has
   */
  modes?: Array<string>;
  /**
   * Parameter extension specific for this CloWM instance
   */
  parameter_extension?: ParameterExtension_Output | null;
  /**
   * The version of Nextflow this workflow version requires.
   */
  nextflow_version: NextflowVersion;
};

export type WorkflowVersionMetadataIn = {
  /**
   * The version of Nextflow this workflow version requires.
   */
  nextflow_version: NextflowVersion;
  /**
   * Nextflow config that overrides the config in the git repository
   */
  nextflow_config?: string | null;
  /**
   * Default container to use for all Nextflow processes that have to container specified
   */
  default_container?: string | null;
};

export type WorkflowVersionMetadataOut = {
  /**
   * The version of Nextflow this workflow version requires.
   */
  nextflow_version: NextflowVersion;
  /**
   * Nextflow config that overrides the config in the git repository
   */
  nextflow_config?: string | null;
  /**
   * Default container to use for all Nextflow processes that have to container specified
   */
  default_container?: string | null;
};

/**
 * Enumeration for the possible status of a workflow version.
 */
export enum WorkflowVersionStatus {
  CREATED = "CREATED",
  DENIED = "DENIED",
  PUBLISHED = "PUBLISHED",
  DEPRECATED = "DEPRECATED",
}

export type WorkflowVersionStatusSchema = {
  /**
   * Status of the workflow version
   */
  status: WorkflowVersionStatus;
};

export type ApiTokenListTokenData = {
  query?: {
    /**
     * UID of the user to filter for. Permission `api_token:list` required if current users is the target.
     */
    uid?: string | null;
  };
};

export type ApiTokenListTokenResponse = Array<ApiTokenOut>;

export type ApiTokenListTokenError = ErrorDetail | HTTPValidationError;

export type ApiTokenCreateTokenData = {
  body: ApiTokenIn;
};

export type ApiTokenCreateTokenResponse = ApiTokenPrivateOut;

export type ApiTokenCreateTokenError = ErrorDetail | HTTPValidationError;

export type ApiTokenGetTokenData = {
  path: {
    /**
     * ID of an API token
     */
    tid: string;
  };
};

export type ApiTokenGetTokenResponse = ApiTokenOut;

export type ApiTokenGetTokenError = ErrorDetail | HTTPValidationError;

export type ApiTokenDeleteTokenData = {
  path: {
    /**
     * ID of an API token
     */
    tid: string;
  };
};

export type ApiTokenDeleteTokenResponse = void;

export type ApiTokenDeleteTokenError = ErrorDetail | HTTPValidationError;

export type AuthLoginData = {
  query?: {
    /**
     * Unique token to validate an invitation
     */
    invitation_token?: string | null;
    /**
     * Will be appended to redirect response in the callback route as URL query parameter `next`
     */
    next?: string | null;
    /**
     * The OIDC provider to use for login
     */
    provider?: OIDCProvider;
  };
};

export type AuthLoginCallbackData = {
  path: {
    provider: OIDCProvider;
  };
};

export type BucketListBucketsData = {
  query?: {
    /**
     * Type of the bucket to get. Ignored when `user` parameter not set
     */
    bucket_type?: BucketType;
    /**
     * UID of the user for whom to fetch the buckets for. Permission `bucket:read_any` required if current user is not the target.
     */
    owner_id?: string | null;
  };
};

export type BucketListBucketsResponse = Array<BucketOut>;

export type BucketListBucketsError = ErrorDetail | HTTPValidationError;

export type BucketCreateBucketData = {
  body: BucketIn;
};

export type BucketCreateBucketResponse = BucketOut;

export type BucketCreateBucketError = ErrorDetail | HTTPValidationError;

export type BucketListBucketOtrsData = {
  query?: {
    /**
     * UID of user who is the current owner.
     */
    current_owner_id?: string | null;
    /**
     * UID of user who will be the new owner.
     */
    new_owner_id?: string | null;
  };
};

export type BucketListBucketOtrsResponse = Array<OwnershipTransferRequestOut>;

export type BucketListBucketOtrsError = ErrorDetail | HTTPValidationError;

export type BucketGetBucketData = {
  path: {
    /**
     * Name of a bucket
     */
    bucket_name: string;
  };
};

export type BucketGetBucketResponse = BucketOut;

export type BucketGetBucketError = ErrorDetail | HTTPValidationError;

export type BucketDeleteBucketData = {
  path: {
    /**
     * Name of a bucket
     */
    bucket_name: string;
  };
  query?: {
    /**
     * Delete even non-empty bucket
     */
    force_delete?: boolean;
  };
};

export type BucketDeleteBucketResponse = void;

export type BucketDeleteBucketError = ErrorDetail | HTTPValidationError;

export type BucketGetBucketOtrData = {
  path: {
    /**
     * Name of a bucket
     */
    bucket_name: string;
  };
};

export type BucketGetBucketOtrResponse = OwnershipTransferRequestOut;

export type BucketGetBucketOtrError = ErrorDetail | HTTPValidationError;

export type BucketCreateBucketOtrData = {
  body: OwnershipTransferRequestIn;
  path: {
    /**
     * Name of a bucket
     */
    bucket_name: string;
  };
};

export type BucketCreateBucketOtrResponse = OwnershipTransferRequestOut;

export type BucketCreateBucketOtrError = ErrorDetail | HTTPValidationError;

export type BucketAcceptBucketOtrData = {
  path: {
    /**
     * Name of a bucket
     */
    bucket_name: string;
  };
};

export type BucketAcceptBucketOtrResponse = BucketOut;

export type BucketAcceptBucketOtrError = ErrorDetail | HTTPValidationError;

export type BucketDeleteBucketOtrData = {
  path: {
    /**
     * Name of a bucket
     */
    bucket_name: string;
  };
};

export type BucketDeleteBucketOtrResponse = void;

export type BucketDeleteBucketOtrError = ErrorDetail | HTTPValidationError;

export type BucketUpdateBucketPublicStateData = {
  body: Body_Bucket_update_bucket_public_state;
  path: {
    /**
     * Name of a bucket
     */
    bucket_name: string;
  };
};

export type BucketUpdateBucketPublicStateResponse = BucketOut;

export type BucketUpdateBucketPublicStateError =
  | ErrorDetail
  | HTTPValidationError;

export type BucketUpdateBucketLimitsData = {
  body: BucketSizeLimits;
  path: {
    /**
     * Name of a bucket
     */
    bucket_name: string;
  };
};

export type BucketUpdateBucketLimitsResponse = BucketOut;

export type BucketUpdateBucketLimitsError = ErrorDetail | HTTPValidationError;

export type BucketPermissionListPermissionsData = {
  query?: {
    /**
     * Scopes of Bucket Permissions to fetch
     */
    permission_scopes?: Array<"read" | "write"> | null;
    /**
     * Status of Bucket Permissions to fetch
     */
    permission_status?: PermissionStatus | null;
  };
};

export type BucketPermissionListPermissionsResponse =
  Array<BucketPermissionOut>;

export type BucketPermissionListPermissionsError =
  | ErrorDetail
  | HTTPValidationError;

export type BucketPermissionCreatePermissionData = {
  body: BucketPermissionIn;
};

export type BucketPermissionCreatePermissionResponse = BucketPermissionOut;

export type BucketPermissionCreatePermissionError =
  | ErrorDetail
  | HTTPValidationError;

export type BucketPermissionListPermissionsPerUserData = {
  path: {
    /**
     * UID of a user
     */
    uid: string;
  };
  query?: {
    /**
     * Scopes of Bucket Permissions to fetch
     */
    permission_scopes?: Array<"read" | "write"> | null;
    /**
     * Status of Bucket Permissions to fetch
     */
    permission_status?: PermissionStatus | null;
  };
};

export type BucketPermissionListPermissionsPerUserResponse =
  Array<BucketPermissionOut>;

export type BucketPermissionListPermissionsPerUserError =
  | ErrorDetail
  | HTTPValidationError;

export type BucketPermissionListPermissionsPerBucketData = {
  path: {
    /**
     * Name of a bucket
     */
    bucket_name: string;
  };
  query?: {
    /**
     * Scopes of Bucket Permissions to fetch
     */
    permission_scopes?: Array<"read" | "write"> | null;
    /**
     * Status of Bucket Permissions to fetch
     */
    permission_status?: PermissionStatus | null;
  };
};

export type BucketPermissionListPermissionsPerBucketResponse =
  Array<BucketPermissionOut>;

export type BucketPermissionListPermissionsPerBucketError =
  | ErrorDetail
  | HTTPValidationError;

export type BucketPermissionGetPermissionForBucketData = {
  path: {
    /**
     * Name of a bucket
     */
    bucket_name: string;
    /**
     * UID of a user
     */
    uid: string;
  };
};

export type BucketPermissionGetPermissionForBucketResponse =
  BucketPermissionOut;

export type BucketPermissionGetPermissionForBucketError =
  | ErrorDetail
  | HTTPValidationError;

export type BucketPermissionUpdatePermissionData = {
  body: BucketPermissionParameters;
  path: {
    /**
     * Name of a bucket
     */
    bucket_name: string;
    /**
     * UID of a user
     */
    uid: string;
  };
};

export type BucketPermissionUpdatePermissionResponse = BucketPermissionOut;

export type BucketPermissionUpdatePermissionError =
  | ErrorDetail
  | HTTPValidationError;

export type BucketPermissionDeletePermissionData = {
  path: {
    /**
     * Name of a bucket
     */
    bucket_name: string;
    /**
     * UID of a user
     */
    uid: string;
  };
};

export type BucketPermissionDeletePermissionResponse = void;

export type BucketPermissionDeletePermissionError =
  | ErrorDetail
  | HTTPValidationError;

export type NewsCreateNewsData = {
  body: NewsIn;
};

export type NewsCreateNewsResponse = NewsOut;

export type NewsCreateNewsError = ErrorDetail | HTTPValidationError;

export type NewsListNewsData = {
  query?: {
    /**
     * Filter for news that are created after this UNIX timestamp
     */
    created_after?: number | null;
    /**
     * Filter for news created by a specific user
     */
    creator_id?: string | null;
    /**
     * Id of the item to start the query from. DO NOT SET MANUALLY.
     */
    id_after?: string | null;
    /**
     * Number of items to list per page
     */
    per_page?: number;
    /**
     * Sort order of items with creation time
     */
    sort?: "asc" | "desc";
  };
};

export type NewsListNewsResponse = Array<NewsOut>;

export type NewsListNewsError = ErrorDetail | HTTPValidationError;

export type NewsListLatestNewsResponse = Array<NewsOut>;

export type NewsListLatestNewsError = ErrorDetail;

export type NewsGetNewsData = {
  path: {
    /**
     * ID of a news event
     */
    nid: string;
  };
};

export type NewsGetNewsResponse = NewsOut;

export type NewsGetNewsError = ErrorDetail | HTTPValidationError;

export type NewsDeleteNewsData = {
  path: {
    /**
     * ID of a news event
     */
    nid: string;
  };
};

export type NewsDeleteNewsResponse = void;

export type NewsDeleteNewsError = ErrorDetail | HTTPValidationError;

export type ResourceCreateResourceData = {
  body: ResourceIn;
};

export type ResourceCreateResourceResponse = ResourceOut;

export type ResourceCreateResourceError = ErrorDetail | HTTPValidationError;

export type ResourceListResourcesData = {
  query?: {
    /**
     * Filter for resource by maintainer. If current user is the same as maintainer ID, permission `resource:list` required, otherwise `resource:list_filter`.
     */
    maintainer_id?: string | null;
    /**
     * Filter resources by a substring in their name.
     */
    name_substring?: string | null;
    /**
     * Filter resources to by the public flag
     */
    public?: boolean | null;
    /**
     * Which versions of the resource to include in the response. Permission `resource:list_filter` required if None or querying for non-public resources, otherwise only permission `resource:list` required.
     */
    version_status?: Array<ResourceVersionStatus> | null;
  };
};

export type ResourceListResourcesResponse = Array<ResourceOut>;

export type ResourceListResourcesError = ErrorDetail | HTTPValidationError;

export type ResourceListSyncRequestsResponse =
  Array<UserSynchronizationRequestOut>;

export type ResourceListSyncRequestsError = ErrorDetail;

export type ResourceListResourceOtrsData = {
  query?: {
    /**
     * UID of user who is the current owner.
     */
    current_owner_id?: string | null;
    /**
     * UID of user who will be the new owner.
     */
    new_owner_id?: string | null;
  };
};

export type ResourceListResourceOtrsResponse =
  Array<OwnershipTransferRequestOut>;

export type ResourceListResourceOtrsError = ErrorDetail | HTTPValidationError;

export type ResourceGetResourceData = {
  path: {
    /**
     * ID of a resource
     */
    rid: string;
  };
  query?: {
    /**
     * Which versions of the resource to include in the response. Permission `resource:read_any` required if None or querying for non-public resources, otherwise only permission `resource:read` required.
     */
    version_status?: Array<ResourceVersionStatus> | null;
  };
};

export type ResourceGetResourceResponse = ResourceOut;

export type ResourceGetResourceError = ErrorDetail | HTTPValidationError;

export type ResourceDeleteResourceData = {
  path: {
    /**
     * ID of a resource
     */
    rid: string;
  };
};

export type ResourceDeleteResourceResponse = void;

export type ResourceDeleteResourceError = ErrorDetail | HTTPValidationError;

export type ResourceGetResourceOtrData = {
  path: {
    /**
     * ID of a resource
     */
    rid: string;
  };
};

export type ResourceGetResourceOtrResponse = OwnershipTransferRequestOut;

export type ResourceGetResourceOtrError = ErrorDetail | HTTPValidationError;

export type ResourceCreateResourceOtrData = {
  body: OwnershipTransferRequestIn;
  path: {
    /**
     * ID of a resource
     */
    rid: string;
  };
};

export type ResourceCreateResourceOtrResponse = OwnershipTransferRequestOut;

export type ResourceCreateResourceOtrError = ErrorDetail | HTTPValidationError;

export type ResourceAcceptResourceOtrData = {
  path: {
    /**
     * ID of a resource
     */
    rid: string;
  };
};

export type ResourceAcceptResourceOtrResponse = ResourceOut;

export type ResourceAcceptResourceOtrError = ErrorDetail | HTTPValidationError;

export type ResourceDeleteResourceOtrData = {
  path: {
    /**
     * ID of a resource
     */
    rid: string;
  };
};

export type ResourceDeleteResourceOtrResponse = void;

export type ResourceDeleteResourceOtrError = ErrorDetail | HTTPValidationError;

export type ResourceVersionListResourceVersionsData = {
  path: {
    /**
     * ID of a resource
     */
    rid: string;
  };
  query?: {
    /**
     * Which versions of the resource to include in the response. Permission `resource:read_any` required if None or querying for non-public resources, otherwise only permission `resource:read` required.
     */
    version_status?: Array<ResourceVersionStatus> | null;
  };
};

export type ResourceVersionListResourceVersionsResponse =
  Array<ResourceVersionOut>;

export type ResourceVersionListResourceVersionsError =
  | ErrorDetail
  | HTTPValidationError;

export type ResourceVersionRequestResourceVersionData = {
  body: ResourceVersionIn;
  path: {
    /**
     * ID of a resource
     */
    rid: string;
  };
};

export type ResourceVersionRequestResourceVersionResponse = ResourceVersionOut;

export type ResourceVersionRequestResourceVersionError =
  | ErrorDetail
  | HTTPValidationError;

export type ResourceVersionGetResourceVersionData = {
  path: {
    /**
     * ID of a resource
     */
    rid: string;
    /**
     * ID of a resource version
     */
    rvid: string;
  };
};

export type ResourceVersionGetResourceVersionResponse = ResourceVersionOut;

export type ResourceVersionGetResourceVersionError =
  | ErrorDetail
  | HTTPValidationError;

export type ResourceVersionResourceFileTreeData = {
  path: {
    /**
     * ID of a resource
     */
    rid: string;
    /**
     * ID of a resource version
     */
    rvid: string;
  };
};

export type ResourceVersionResourceFileTreeResponse = Array<FileTree>;

export type ResourceVersionResourceFileTreeError =
  | ErrorDetail
  | HTTPValidationError;

export type ResourceVersionRequestResourceVersionReviewData = {
  path: {
    /**
     * ID of a resource
     */
    rid: string;
    /**
     * ID of a resource version
     */
    rvid: string;
  };
};

export type ResourceVersionRequestResourceVersionReviewResponse =
  ResourceVersionOut;

export type ResourceVersionRequestResourceVersionReviewError =
  | ErrorDetail
  | HTTPValidationError;

export type ResourceVersionRequestResourceVersionSyncData = {
  body: UserSynchronizationRequestIn;
  path: {
    /**
     * ID of a resource
     */
    rid: string;
    /**
     * ID of a resource version
     */
    rvid: string;
  };
};

export type ResourceVersionRequestResourceVersionSyncResponse =
  ResourceVersionOut;

export type ResourceVersionRequestResourceVersionSyncError =
  | ErrorDetail
  | HTTPValidationError;

export type ResourceVersionResourceVersionReviewData = {
  body: UserRequestAnswer;
  path: {
    /**
     * ID of a resource
     */
    rid: string;
    /**
     * ID of a resource version
     */
    rvid: string;
  };
};

export type ResourceVersionResourceVersionReviewResponse = ResourceVersionOut;

export type ResourceVersionResourceVersionReviewError =
  | ErrorDetail
  | HTTPValidationError;

export type ResourceVersionResourceVersionSyncData = {
  body: UserRequestAnswer;
  path: {
    /**
     * ID of a resource
     */
    rid: string;
    /**
     * ID of a resource version
     */
    rvid: string;
  };
};

export type ResourceVersionResourceVersionSyncResponse = ResourceVersionOut;

export type ResourceVersionResourceVersionSyncError =
  | ErrorDetail
  | HTTPValidationError;

export type ResourceVersionResourceVersionLatestData = {
  path: {
    /**
     * ID of a resource
     */
    rid: string;
    /**
     * ID of a resource version
     */
    rvid: string;
  };
};

export type ResourceVersionResourceVersionLatestResponse = ResourceVersionOut;

export type ResourceVersionResourceVersionLatestError =
  | ErrorDetail
  | HTTPValidationError;

export type ResourceVersionDeleteResourceVersionClusterData = {
  path: {
    /**
     * ID of a resource
     */
    rid: string;
    /**
     * ID of a resource version
     */
    rvid: string;
  };
};

export type ResourceVersionDeleteResourceVersionClusterResponse =
  ResourceVersionOut;

export type ResourceVersionDeleteResourceVersionClusterError =
  | ErrorDetail
  | HTTPValidationError;

export type ResourceVersionDeleteResourceVersionS3Data = {
  path: {
    /**
     * ID of a resource
     */
    rid: string;
    /**
     * ID of a resource version
     */
    rvid: string;
  };
};

export type ResourceVersionDeleteResourceVersionS3Response = ResourceVersionOut;

export type ResourceVersionDeleteResourceVersionS3Error =
  | ErrorDetail
  | HTTPValidationError;

export type S3KeyGetUserKeysData = {
  path: {
    /**
     * UID of a user
     */
    uid: string;
  };
};

export type S3KeyGetUserKeysResponse = Array<S3Key>;

export type S3KeyGetUserKeysError = ErrorDetail | HTTPValidationError;

export type S3KeyCreateUserKeyData = {
  path: {
    /**
     * UID of a user
     */
    uid: string;
  };
};

export type S3KeyCreateUserKeyResponse = S3Key;

export type S3KeyCreateUserKeyError = ErrorDetail | HTTPValidationError;

export type S3KeyGetUserKeyData = {
  path: {
    /**
     * ID of the S3 access key
     */
    access_id: string;
    /**
     * UID of a user
     */
    uid: string;
  };
};

export type S3KeyGetUserKeyResponse = S3Key;

export type S3KeyGetUserKeyError = ErrorDetail | HTTPValidationError;

export type S3KeyDeleteUserKeyData = {
  path: {
    /**
     * ID of the S3 access key
     */
    access_id: string;
    /**
     * UID of a user
     */
    uid: string;
  };
};

export type S3KeyDeleteUserKeyResponse = void;

export type S3KeyDeleteUserKeyError = ErrorDetail | HTTPValidationError;

export type UserCreateUserData = {
  body: UserIn;
};

export type UserCreateUserResponse = UserOutExtended;

export type UserCreateUserError = ErrorDetail | HTTPValidationError;

export type UserListUsersData = {
  query?: {
    /**
     * Filter users by their role. If multiple are selected, they are concatenating by an OR Expression.
     */
    filter_roles?: Array<RoleEnum> | null;
    /**
     * Filter users by a substring in their name.
     */
    name_substring?: string | null;
  };
};

export type UserListUsersResponse = Array<UserOutExtended>;

export type UserListUsersError = ErrorDetail | HTTPValidationError;

export type UserSearchUsersData = {
  query: {
    /**
     * Filter users by a substring in their name.
     */
    name_substring: string;
  };
};

export type UserSearchUsersResponse = Array<UserOut>;

export type UserSearchUsersError = ErrorDetail | HTTPValidationError;

export type UserGetLoggedInUserResponse = UserOutExtended;

export type UserGetLoggedInUserError = ErrorDetail;

export type UserGetUserData = {
  path: {
    /**
     * UID of a user
     */
    uid: string;
  };
};

export type UserGetUserResponse = UserOut;

export type UserGetUserError = ErrorDetail | HTTPValidationError;

export type UserUpdateRolesData = {
  body: UserRoles;
  path: {
    /**
     * UID of a user
     */
    uid: string;
  };
};

export type UserUpdateRolesResponse = UserOutExtended;

export type UserUpdateRolesError = ErrorDetail | HTTPValidationError;

export type UserResendInvitationData = {
  path: {
    /**
     * UID of a user
     */
    uid: string;
  };
};

export type UserResendInvitationResponse = UserOutExtended;

export type UserResendInvitationError = ErrorDetail | HTTPValidationError;

export type WorkflowCreateWorkflowData = {
  body: WorkflowIn;
};

export type WorkflowCreateWorkflowResponse = WorkflowOut;

export type WorkflowCreateWorkflowError = ErrorDetail | HTTPValidationError;

export type WorkflowListWorkflowsData = {
  query?: {
    /**
     * Filter for workflow by developer. If current user is the developer, permission `workflow:list` required, otherwise `workflow:list_filter`.
     */
    developer_id?: string | null;
    /**
     * Filter workflows by a substring in their name.
     */
    name_substring?: string | null;
    /**
     * Which versions of the workflow to include in the response. Permission `workflow:list_filter` required, unless `developer_id` is provided and current user is developer, then only permission `workflow:list` required. Default `PUBLISHED` and `DEPRECATED`.
     */
    version_status?: Array<WorkflowVersionStatus> | null;
  };
};

export type WorkflowListWorkflowsResponse = Array<WorkflowOut>;

export type WorkflowListWorkflowsError = ErrorDetail | HTTPValidationError;

export type WorkflowListWorkflowOtrsData = {
  query?: {
    /**
     * UID of user who is the current owner.
     */
    current_owner_id?: string | null;
    /**
     * UID of user who will be the new owner.
     */
    new_owner_id?: string | null;
  };
};

export type WorkflowListWorkflowOtrsResponse =
  Array<OwnershipTransferRequestOut>;

export type WorkflowListWorkflowOtrsError = ErrorDetail | HTTPValidationError;

export type WorkflowGetDeveloperWorkflowStatisticsData = {
  query?: {
    /**
     * Filter by the developer of the workflows
     */
    developer_id?: string | null;
    /**
     * Filter by workflow executions before this date
     */
    end?: string | null;
    /**
     * Filter by workflow executions after this date
     */
    start?: string | null;
    /**
     * Filter by workflow IDs
     */
    workflow_id?: Array<string> | null;
  };
};

export type WorkflowGetDeveloperWorkflowStatisticsResponse =
  Array<AnonymizedWorkflowExecution>;

export type WorkflowGetDeveloperWorkflowStatisticsError =
  | ErrorDetail
  | HTTPValidationError;

export type WorkflowGetWorkflowData = {
  path: {
    /**
     * ID of a workflow
     */
    wid: string;
  };
  query?: {
    /**
     * Which versions of the workflow to include in the response. Permission `workflow:read_any` required if you are not the developer of this workflow. Default `PUBLISHED` and `DEPRECATED`
     */
    version_status?: Array<WorkflowVersionStatus> | null;
  };
};

export type WorkflowGetWorkflowResponse = WorkflowOut;

export type WorkflowGetWorkflowError = ErrorDetail | HTTPValidationError;

export type WorkflowDeleteWorkflowData = {
  path: {
    /**
     * ID of a workflow
     */
    wid: string;
  };
};

export type WorkflowDeleteWorkflowResponse = void;

export type WorkflowDeleteWorkflowError = ErrorDetail | HTTPValidationError;

export type WorkflowGetWorkflowOtrData = {
  path: {
    /**
     * ID of a workflow
     */
    wid: string;
  };
};

export type WorkflowGetWorkflowOtrResponse = OwnershipTransferRequestOut;

export type WorkflowGetWorkflowOtrError = ErrorDetail | HTTPValidationError;

export type WorkflowCreateWorkflowOtrData = {
  body: OwnershipTransferRequestIn;
  path: {
    /**
     * ID of a workflow
     */
    wid: string;
  };
};

export type WorkflowCreateWorkflowOtrResponse = OwnershipTransferRequestOut;

export type WorkflowCreateWorkflowOtrError = ErrorDetail | HTTPValidationError;

export type WorkflowAcceptWorkflowOtrData = {
  path: {
    /**
     * ID of a workflow
     */
    wid: string;
  };
};

export type WorkflowAcceptWorkflowOtrResponse = WorkflowOut;

export type WorkflowAcceptWorkflowOtrError = ErrorDetail | HTTPValidationError;

export type WorkflowDeleteWorkflowOtrData = {
  path: {
    /**
     * ID of a workflow
     */
    wid: string;
  };
};

export type WorkflowDeleteWorkflowOtrResponse = void;

export type WorkflowDeleteWorkflowOtrError = ErrorDetail | HTTPValidationError;

export type WorkflowGetWorkflowStatisticsData = {
  path: {
    /**
     * ID of a workflow
     */
    wid: string;
  };
};

export type WorkflowGetWorkflowStatisticsResponse = Array<WorkflowStatistic>;

export type WorkflowGetWorkflowStatisticsError =
  | ErrorDetail
  | HTTPValidationError;

export type WorkflowUpdateWorkflowData = {
  body: WorkflowUpdate;
  path: {
    /**
     * ID of a workflow
     */
    wid: string;
  };
};

export type WorkflowUpdateWorkflowResponse = WorkflowVersion;

export type WorkflowUpdateWorkflowError = ErrorDetail | HTTPValidationError;

export type WorkflowCredentialsGetWorkflowCredentialsData = {
  path: {
    /**
     * ID of a workflow
     */
    wid: string;
  };
};

export type WorkflowCredentialsGetWorkflowCredentialsResponse =
  WorkflowCredentialsOut;

export type WorkflowCredentialsGetWorkflowCredentialsError =
  | ErrorDetail
  | HTTPValidationError;

export type WorkflowCredentialsUpdateWorkflowCredentialsData = {
  body: WorkflowCredentialsIn;
  path: {
    /**
     * ID of a workflow
     */
    wid: string;
  };
};

export type WorkflowCredentialsUpdateWorkflowCredentialsResponse = unknown;

export type WorkflowCredentialsUpdateWorkflowCredentialsError =
  | ErrorDetail
  | HTTPValidationError;

export type WorkflowCredentialsDeleteWorkflowCredentialsData = {
  path: {
    /**
     * ID of a workflow
     */
    wid: string;
  };
};

export type WorkflowCredentialsDeleteWorkflowCredentialsResponse = void;

export type WorkflowCredentialsDeleteWorkflowCredentialsError =
  | ErrorDetail
  | HTTPValidationError;

export type WorkflowExecutionStartWorkflowData = {
  body: WorkflowExecutionIn;
};

export type WorkflowExecutionStartWorkflowResponse = WorkflowExecutionOut;

export type WorkflowExecutionStartWorkflowError =
  | ErrorDetail
  | HTTPValidationError;

export type WorkflowExecutionListWorkflowExecutionsData = {
  query?: {
    /**
     * Filter for status of workflow execution
     */
    execution_status?: Array<WorkflowExecutionStatus> | null;
    /**
     * Filter for workflow executions by a user. If none, Permission `workflow_execution:read_any` required.
     */
    executor_id?: string | null;
    /**
     * Id of the item to start the query from. DO NOT SET MANUALLY.
     */
    id_after?: string | null;
    /**
     * Number of items to list per page
     */
    per_page?: number;
    /**
     * Sort order of items with creation time
     */
    sort?: "asc" | "desc";
    /**
     * Filter for workflow executions that started after this UNIX timestamp
     */
    start_after?: number | null;
    /**
     * Filter for workflow executions that started before this UNIX timestamp
     */
    start_before?: number | null;
    /**
     * Filter for workflow
     */
    workflow_id?: string | null;
    /**
     * Filter for workflow version
     */
    workflow_version_id?: string | null;
  };
};

export type WorkflowExecutionListWorkflowExecutionsResponse =
  Array<WorkflowExecutionOut>;

export type WorkflowExecutionListWorkflowExecutionsError =
  | ErrorDetail
  | HTTPValidationError;

export type WorkflowExecutionStartArbitraryWorkflowData = {
  body: DevWorkflowExecutionIn;
};

export type WorkflowExecutionStartArbitraryWorkflowResponse =
  WorkflowExecutionOut;

export type WorkflowExecutionStartArbitraryWorkflowError =
  | ErrorDetail
  | HTTPValidationError;

export type WorkflowExecutionGetWorkflowExecutionData = {
  path: {
    /**
     * ID of a workflow execution.
     */
    eid: string;
  };
};

export type WorkflowExecutionGetWorkflowExecutionResponse =
  WorkflowExecutionOut;

export type WorkflowExecutionGetWorkflowExecutionError =
  | ErrorDetail
  | HTTPValidationError;

export type WorkflowExecutionDeleteWorkflowExecutionData = {
  path: {
    /**
     * ID of a workflow execution.
     */
    eid: string;
  };
};

export type WorkflowExecutionDeleteWorkflowExecutionResponse = void;

export type WorkflowExecutionDeleteWorkflowExecutionError =
  | ErrorDetail
  | HTTPValidationError;

export type WorkflowExecutionGetWorkflowExecutionParamsData = {
  path: {
    /**
     * ID of a workflow execution.
     */
    eid: string;
  };
};

export type WorkflowExecutionGetWorkflowExecutionParamsResponse = {
  [key: string]: unknown;
};

export type WorkflowExecutionGetWorkflowExecutionParamsError =
  | ErrorDetail
  | HTTPValidationError;

export type WorkflowExecutionCancelWorkflowExecutionData = {
  path: {
    /**
     * ID of a workflow execution.
     */
    eid: string;
  };
};

export type WorkflowExecutionCancelWorkflowExecutionResponse = void;

export type WorkflowExecutionCancelWorkflowExecutionError =
  | ErrorDetail
  | HTTPValidationError;

export type WorkflowModeGetWorkflowModeData = {
  path: {
    /**
     * ID of a workflow mode
     */
    mode_id: string;
  };
};

export type WorkflowModeGetWorkflowModeResponse = WorkflowModeOut;

export type WorkflowModeGetWorkflowModeError =
  | ErrorDetail
  | HTTPValidationError;

export type WorkflowVersionListWorkflowVersionData = {
  path: {
    /**
     * ID of a workflow
     */
    wid: string;
  };
  query?: {
    /**
     * Which versions of the workflow to include in the response. Permission `workflow:list_filter` required if you are not the developer of this workflow. Default `PUBLISHED` and `DEPRECATED`
     */
    version_status?: Array<WorkflowVersionStatus> | null;
  };
};

export type WorkflowVersionListWorkflowVersionResponse = Array<WorkflowVersion>;

export type WorkflowVersionListWorkflowVersionError =
  | ErrorDetail
  | HTTPValidationError;

export type WorkflowVersionGetWorkflowVersionData = {
  path: {
    /**
     * Git commit `git_commit_hash` of specific version or `latest`.
     */
    git_commit_hash: string;
    /**
     * ID of a workflow
     */
    wid: string;
  };
};

export type WorkflowVersionGetWorkflowVersionResponse = WorkflowVersion;

export type WorkflowVersionGetWorkflowVersionError =
  | ErrorDetail
  | HTTPValidationError;

export type WorkflowVersionUpdateWorkflowVersionStatusData = {
  body: WorkflowVersionStatusSchema;
  path: {
    /**
     * Git commit git_commit_hash of specific version.
     */
    git_commit_hash: string;
    /**
     * ID of a workflow
     */
    wid: string;
  };
};

export type WorkflowVersionUpdateWorkflowVersionStatusResponse =
  WorkflowVersion;

export type WorkflowVersionUpdateWorkflowVersionStatusError =
  | ErrorDetail
  | HTTPValidationError;

export type WorkflowVersionGetWorkflowVersionMetadataData = {
  path: {
    /**
     * Git commit git_commit_hash of specific version.
     */
    git_commit_hash: string;
    /**
     * ID of a workflow
     */
    wid: string;
  };
};

export type WorkflowVersionGetWorkflowVersionMetadataResponse =
  WorkflowVersionMetadataOut;

export type WorkflowVersionGetWorkflowVersionMetadataError =
  | ErrorDetail
  | HTTPValidationError;

export type WorkflowVersionUpdateWorkflowVersionMetadataData = {
  body: WorkflowVersionMetadataIn;
  path: {
    /**
     * Git commit git_commit_hash of specific version.
     */
    git_commit_hash: string;
    /**
     * ID of a workflow
     */
    wid: string;
  };
};

export type WorkflowVersionUpdateWorkflowVersionMetadataResponse =
  WorkflowVersionMetadataOut;

export type WorkflowVersionUpdateWorkflowVersionMetadataError =
  | ErrorDetail
  | HTTPValidationError;

export type WorkflowVersionDeprecateWorkflowVersionData = {
  path: {
    /**
     * Git commit git_commit_hash of specific version.
     */
    git_commit_hash: string;
    /**
     * ID of a workflow
     */
    wid: string;
  };
};

export type WorkflowVersionDeprecateWorkflowVersionResponse = WorkflowVersion;

export type WorkflowVersionDeprecateWorkflowVersionError =
  | ErrorDetail
  | HTTPValidationError;

export type WorkflowVersionUpdateWorkflowVersionParameterExtensionData = {
  body: ParameterExtension_Input;
  path: {
    /**
     * Git commit git_commit_hash of specific version.
     */
    git_commit_hash: string;
    /**
     * ID of a workflow
     */
    wid: string;
  };
};

export type WorkflowVersionUpdateWorkflowVersionParameterExtensionResponse =
  WorkflowVersion;

export type WorkflowVersionUpdateWorkflowVersionParameterExtensionError =
  | ErrorDetail
  | HTTPValidationError;

export type WorkflowVersionDownloadWorkflowDocumentationData = {
  path: {
    /**
     * Git commit git_commit_hash of specific version.
     */
    git_commit_hash: string;
    /**
     * ID of a workflow
     */
    wid: string;
  };
  query?: {
    /**
     * Specify which type of documentation the client wants to fetch
     */
    document?: DocumentationEnum;
    /**
     * Workflow Mode
     */
    mode_id?: string | null;
  };
};

export type WorkflowVersionDownloadWorkflowDocumentationResponse = unknown;

export type WorkflowVersionDownloadWorkflowDocumentationError =
  | ErrorDetail
  | HTTPValidationError;

export type WorkflowVersionUploadWorkflowVersionIconData = {
  body: Body_Workflow_Version_upload_workflow_version_icon;
  path: {
    /**
     * Git commit git_commit_hash of specific version.
     */
    git_commit_hash: string;
    /**
     * ID of a workflow
     */
    wid: string;
  };
};

export type WorkflowVersionUploadWorkflowVersionIconResponse = IconUpdateOut;

export type WorkflowVersionUploadWorkflowVersionIconError =
  | ErrorDetail
  | HTTPValidationError;

export type WorkflowVersionDeleteWorkflowVersionIconData = {
  path: {
    /**
     * Git commit git_commit_hash of specific version.
     */
    git_commit_hash: string;
    /**
     * ID of a workflow
     */
    wid: string;
  };
};

export type WorkflowVersionDeleteWorkflowVersionIconResponse = void;

export type WorkflowVersionDeleteWorkflowVersionIconError =
  | ErrorDetail
  | HTTPValidationError;
